@@ -296,7 +296,7 @@ class StreamMsgType(enum.Enum):
     QUOTE = 21
     TRADE = 22
     OPEN_INTEREST = 23
-
+    OHLCVC = 24
     # Tape commands
     START = 30
     RESTART = 31
@@ -550,7 +550,7 @@ class TradeCondition(enum.Enum):
     SINGLE_LEG_FLOOR_TRADE = 129
     MULTI_LEG_AUTO_ELECTRONIC_TRADE = 130
     MULTI_LEG_AUCTION = 131
-    MULTI_LEG_CROSS = -132
+    MULTI_LEG_CROSS = 132
     MULTI_LEG_FLOOR_TRADE = 133
     MULTI_LEG_AUTO_ELEC_TRADE_AGAINST_SINGLE_LEG = 134
     STOCK_OPTIONS_AUCTION = 135
